@@ -37,7 +37,7 @@ OC.L10N.register(
     "Timezone" : "Tydsone",
     "List view" : "Lysaansig",
     "Actions" : "Aksies",
-    "Keyboard shortcuts" : "Sneltoetse",
+    "Files" : "Lêer ",
     "Update" : "Werk by",
     "Location" : "Ligging",
     "Description" : "Beskrywing",
