@@ -37,7 +37,7 @@ OC.L10N.register(
     "Actions" : "Acciones",
     "or" : "o",
     "General" : "General",
-    "Keyboard shortcuts" : "Atajos del teclado",
+    "Files" : "Archivo",
     "Update" : "Actualizar",
     "Location" : "Ubicación",
     "Description" : "Descripción",
